@@ -21,6 +21,7 @@ class SecondOrderLINEEnsmallen(EnsmallenEmbedder):
         use_scale_free_distribution: bool = True,
         node_embedding_path: Optional[str] = None,
         contextual_node_embedding_path: Optional[str] = None,
+        dtype: str = "f32",
         random_state: int = 42,
         verbose: bool = False,
         enable_cache: bool = False
@@ -50,6 +51,8 @@ class SecondOrderLINEEnsmallen(EnsmallenEmbedder):
             Path where to mmap and store the contextual nodes embedding.
             This is necessary to embed large graphs whose embedding will not
             fit into the available main memory.
+        dtype: str = "f32"
+            The data type to be employed, by default f32.
         random_state: int = 42
             Random state to reproduce the embeddings.
         verbose: bool = False
@@ -66,6 +69,7 @@ class SecondOrderLINEEnsmallen(EnsmallenEmbedder):
             use_scale_free_distribution=use_scale_free_distribution,
             node_embedding_path=node_embedding_path,
             contextual_node_embedding_path=contextual_node_embedding_path,
+            dtype=dtype,
             verbose=verbose
         )
 
