@@ -24,6 +24,7 @@ class SiameseEnsmallen(EnsmallenEmbedder):
         learning_rate: float = 0.1,
         learning_rate_decay: float = 0.9,
         node_embedding_path: Optional[str] = None,
+        dtype: str = "f32",
         random_state: int = 42,
         verbose: bool = False,
         enable_cache: bool = False,
@@ -48,6 +49,8 @@ class SiameseEnsmallen(EnsmallenEmbedder):
             Path where to mmap and store the nodes embedding.
             This is necessary to embed large graphs whose embedding will not
             fit into the available main memory.
+        dtype: str = "f32"
+            The data type to be employed, by default f32.
         random_state: int = 42
             Random state to reproduce the embeddings.
         verbose: bool = False
@@ -63,6 +66,7 @@ class SiameseEnsmallen(EnsmallenEmbedder):
             learning_rate_decay=learning_rate_decay,
             node_embedding_path=node_embedding_path,
             verbose=verbose,
+            dtype=dtype,
             **paths
         )
 
